@@ -3,21 +3,12 @@
 # differently.
 
 package App::Tel::CiscoLogColors;
-#use parent 'ColorObject';
+use parent 'App::Tel::ColorObject';
 use Term::ANSIColor;
 use strict;
+use warnings;
 
-$Term::ANSIColor::AUTORESET++;         # reset color after each print
-$SIG{INT} = sub { print "\n"; exit; }; # reset color after Ctrl-C
-
-
-
-sub new {
-    my $proto = shift;
-    my $class = ref($proto) || $proto;
-
-    return bless( {}, $class);
-}
+our $VERSION = eval '0.1';
 
 sub colorize {
     my $self = shift;
